@@ -1,5 +1,5 @@
 .onAttach <- function(...){
 	packageStartupMessage("Much appreciate for using CMplot.")
     packageStartupMessage("Full description, Bug report, Suggestion and the latest codes:")
-    packageStartupMessage("https://github.com/YinLiLin/R-CMplot")
+    packageStartupMessage("https://github.com/YinLiLin/CMplot")
 }
